summaryrefslogtreecommitdiffstats
path: root/templates/annotated/systray1.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/systray1.py')
-rw-r--r--templates/annotated/systray1.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/templates/annotated/systray1.py b/templates/annotated/systray1.py
index faf97e0..3c1d3d5 100644
--- a/templates/annotated/systray1.py
+++ b/templates/annotated/systray1.py
@@ -37,9 +37,9 @@ import sys
from qt import TQLabel, TQWidget, SIGNAL
from tdecore import TDEApplication, KIcon, KIconLoader
-from tdeui import KMainWindow, KSystemTray
+from tdeui import TDEMainWindow, KSystemTray
-# This template uses KMainWindow as the main window widget
+# This template uses TDEMainWindow as the main window widget
# It solves the problem described in systray.py by using
# a flag to control the return value from queryClose - if
# :quit" is signalled from anywhere EXCEPT the system tray
@@ -47,9 +47,9 @@ from tdeui import KMainWindow, KSystemTray
# value for queryClose, it stops the application from shutting
# down; if self.exitFlag is True, the application shuts down
-class MainWin (KMainWindow):
+class MainWin (TDEMainWindow):
def __init__ (self, *args):
- apply (KMainWindow.__init__, (self,) + args)
+ apply (TDEMainWindow.__init__, (self,) + args)
self.exitFlag = False